@@ -1,24 +1,12 @@
-from django import forms
+from django import forms, urls
 from django.conf import settings
 from django.views import i18n
-from django.utils import safestring
-from django.utils.translation import ugettext_lazy as _, get_language
+from django.utils.translation import ugettext_lazy as _
 from django.contrib.staticfiles.storage import staticfiles_storage
 
-try:
-    from django import urls
-except ImportError:
-    from django.core import urlresolvers as urls
-
 import recurrence
 from recurrence import exceptions
 
-# Django 1.5+ compatibility
-try:
-    import json
-except ImportError:
-    import django.utils.simplejson as json
-
 
 class RecurrenceWidget(forms.Textarea):
 
@@ -27,29 +15,16 @@ class RecurrenceWidget(forms.Textarea):
         defaults = {'class': 'recurrence-widget'}
         if attrs is not None:
             defaults.update(attrs)
-        super(RecurrenceWidget, self).__init__(defaults)
-
-    def render(self, name, value, attrs=None, renderer=None):
-        if value is None:
-            value = ''
-        elif isinstance(value, recurrence.Recurrence):
-            value = recurrence.serialize(value)
-
-        widget_init_js = (
-            '<script type="text/javascript">'
-            'recurrence.language_code =\'%s\';'
-            'new recurrence.widget.Widget(\'%s\', %s);'
-            '</script>'
-        ) % (get_language(), attrs['id'], json.dumps(self.js_widget_options))
-
-        return safestring.mark_safe(u'%s\n%s' % (
-            super(RecurrenceWidget, self).render(name, value, attrs),
-            widget_init_js))
+        super().__init__(defaults)
 
     def get_media(self):
+        extra = '' if settings.DEBUG else '.min'
         js = [
+            'vendor/jquery/jquery%s.js' % extra,
+            'admin/js/jquery.init.js',
             staticfiles_storage.url('recurrence/js/recurrence.js'),
             staticfiles_storage.url('recurrence/js/recurrence-widget.js'),
+            staticfiles_storage.url('recurrence/js/recurrence-widget.init.js'),
         ]
         i18n_media = find_recurrence_i18n_js_catalog()
         if i18n_media:
@@ -142,7 +117,7 @@ class RecurrenceField(forms.CharField):
                 recurrence.HOURLY, recurrence.MINUTELY,
                 recurrence.SECONDLY,
             )
-        super(RecurrenceField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def clean(self, value):
         """
